Changelog
=========

### v0.1.0 / 2022-10-04

##### Features

  - Add Django 3.2 support (#27).

##### Fixes

  - Fix release workflow (#12).

##### Misc

  - Update flake8 from 3.8.4 to 3.9.2 (#13, #15, #21).
  - Update isort from 5.7.0 to 5.8.0 (#17).
  - Update pytest-cov from 2.11.1 to 2.12.0 (#23).
  - Update black from 20.8b1 to 22.8.0 (#19, #27).
  - Update codecov-action from v1 to v2 (#25).
  - Pin importlib-metadata to 2.1.3 (#31).

### v0.0.2 / 2021-02-22

##### Features

  - Add decorator `superuser_required_or_403()` (#9).
  - Add Python 3.9 support (#7).
  
##### Misc

  - Add release workflow to PyPI with GitHub Actions.
  - Add project urls in `setup.py` metadata (#10).
  - Tweak black and isort config (#5, #6, #8).

### v0.0.1 / 2021-02-08

  - First version, released on an unsuspecting world.
